#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 what4
version:              1.6.1
visibility:           public
id:                   what4-1.6.1-1EsLCS7HpkV9Hkyjrfh2QG
key:                  what4-1.6.1-1EsLCS7HpkV9Hkyjrfh2QG
license:              BSD-3-Clause
copyright:            (c) Galois, Inc 2014-2023
maintainer:           rscott@galois.com, kquick@galois.com
author:               Galois Inc.
homepage:             https://github.com/GaloisInc/what4
synopsis:             Solver-agnostic symbolic values support for issuing queries
description:
    What4 is a generic library for representing values as symbolic formulae which may
    contain references to symbolic values, representing unknown variables.
    It provides support for communicating with a variety of SAT and SMT solvers,
    including Z3, CVC4, CVC5, Yices, Bitwuzla, Boolector, STP, and dReal.
    The data representation types make heavy use of GADT-style type indices
    to ensure type-correct manipulation of symbolic values.

category:             Formal Methods, Theorem Provers, Symbolic Computation, SMT
abi:                  77b94b129c24f666a8fe29b2a5d5bf11
exposed:              True
exposed-modules:
    Test.Verification What4.BaseTypes What4.Concrete What4.Config
    What4.Expr What4.Expr.Allocator What4.Expr.App What4.Expr.AppTheory
    What4.Expr.ArrayUpdateMap What4.Expr.BoolMap What4.Expr.Builder
    What4.Expr.GroundEval What4.Expr.MATLAB What4.Expr.Simplify
    What4.Expr.StringSeq What4.Expr.UnaryBV
    What4.Expr.VarIdentification What4.Expr.WeightedSum What4.FloatMode
    What4.FunctionName What4.IndexLit What4.Interface
    What4.InterpretedFloatingPoint What4.LabeledPred What4.Panic
    What4.Partial What4.ProblemFeatures What4.ProgramLoc
    What4.Protocol.Online What4.Protocol.PolyRoot
    What4.Protocol.ReadDecimal What4.Protocol.SExp
    What4.Protocol.SMTLib2 What4.Protocol.SMTLib2.Parse
    What4.Protocol.SMTLib2.Response What4.Protocol.SMTLib2.Syntax
    What4.Protocol.SMTWriter What4.Protocol.VerilogWriter
    What4.Protocol.VerilogWriter.ABCVerilog
    What4.Protocol.VerilogWriter.AST
    What4.Protocol.VerilogWriter.Backend What4.SFloat What4.SWord
    What4.SatResult What4.SemiRing What4.Serialize.FastSExpr
    What4.Serialize.Log What4.Serialize.Normalize
    What4.Serialize.Parser What4.Serialize.Printer
    What4.Serialize.SETokens What4.Solver What4.Solver.Adapter
    What4.Solver.Bitwuzla What4.Solver.Boolector What4.Solver.CVC4
    What4.Solver.CVC5 What4.Solver.DReal What4.Solver.ExternalABC
    What4.Solver.STP What4.Solver.Yices What4.Solver.Z3
    What4.SpecialFunctions What4.Symbol What4.Utils.AbstractDomains
    What4.Utils.AnnotatedMap What4.Utils.Arithmetic
    What4.Utils.BVDomain What4.Utils.BVDomain.Arith
    What4.Utils.BVDomain.Bitwise What4.Utils.BVDomain.XOR
    What4.Utils.Complex What4.Utils.Endian What4.Utils.Environment
    What4.Utils.FloatHelpers What4.Utils.HandleReader
    What4.Utils.IncrHash What4.Utils.LeqMap What4.Utils.MonadST
    What4.Utils.OnlyIntRepr What4.Utils.Process
    What4.Utils.ResolveBounds.BV What4.Utils.Serialize
    What4.Utils.Streams What4.Utils.StringLiteral What4.Utils.Versions
    What4.Utils.Word16String What4.WordMap

import-dirs:          /usr/lib/ghc-9.6.6/site-local/what4-1.6.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/what4-1.6.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/what4-1.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-what4
hs-libraries:         HSwhat4-1.6.1-1EsLCS7HpkV9Hkyjrfh2QG
depends:
    BoundedChan-1.0.3.0-KC4GwTTdtFBGyIaMAN8c52
    async-2.2.6-ITRC11Ox8a3Q3zDt3UwKf
    attoparsec-0.14.4-HxFEqrzE4jlDGISwMuQFm7 base-4.18.2.1
    bifunctors-5.6.3-40xKQKgYXzc6u9JTwdJvAF
    bimap-0.5.0-A9szvYrn3paLejWU2spZ7D
    bv-sized-1.0.7-8FaR5vGQvIoGcmLSe8TjBk bytestring-0.11.5.3
    concurrent-extra-0.7.0.12-KH1WHAIlktvC98kV0oCWoi
    config-value-0.8.3-IWIlPmbx9u07ZPnTUBDeDU containers-0.6.7
    deepseq-1.4.8.1 deriving-compat-0.6.8-GzAYqUoOEJpLkiPpssgwle
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    fingertree-0.1.6.3-GIrjDkIwow6LTi6FTewdnC ghc-prim-0.10.0
    hashable-1.4.7.0-Ws19qMM2f99bApawlWBTg
    hashtables-1.4.2-1ESeJWmOdzEDJy2LHeuYn8
    io-streams-1.5.2.2-Ek00NGLRdErAKRkSN3qZFB
    lens-5.3.5-KA5gcUGZYMJ4Yj2DW4uyDf
    libBF-0.6.7-IZc3L41CjJ6Hty0pMRi4hS
    megaparsec-9.7.1-3v9USGunK8PJV50Lxdl0PB mtl-2.3.1
    ordered-containers-0.2.4-EUEMYtfKfUuHJdeMg0LFix
    panic-0.4.0.1-LjSerD2Hu1fK37HhFAQEbK
    parameterized-utils-2.1.11.0-LZTfJTspZHiGY1CPTabQqW parsec-3.1.16.1
    prettyprinter-1.7.2-1DGqCnBpxP9HlPCcGuqpc1 process-1.6.19.0
    s-cargot-0.1.6.0-AdoIWCQYQv65m9nFkZawYg
    scientific-0.3.8.1-Chb8huA5Cwn7PjEJBSEbMQ stm-2.5.1.0
    template-haskell-2.20.0.0 temporary-1.3-6srFELH6ZJ85EWwSBp1olQ
    text-2.0.2 th-lift-0.8.7-JMijAGUD56uaCh66C6Lgg
    th-lift-instances-0.1.20-JZQs0SgR0NF8iOjWUtJL87 time-1.12.2
    transformers-0.6.1.0 unliftio-0.2.25.1-7sR1Ziz3z9kDMr2BTZq7dj
    unordered-containers-0.2.21-8KUdGsL7zFhFWAw4aaEQtP
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    vector-0.13.2.0-KNP2q6eDEp8AmnRr9wgHHB
    versions-6.0.8-IEtpDqWw2ccXgiFVO4tH
    zenc-0.1.2-t43Aqok0QV9NbZ531d0UU

haddock-interfaces:   /usr/share/doc/haskell-what4/html/what4.haddock
haddock-html:         /usr/share/doc/haskell-what4/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

